NoConnectionException class

Device has no internet connection (SocketException, DNS failure, etc.).

Inheritance

Constructors

NoConnectionException(String message, {dynamic originalError, StackTrace? stackTrace})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
originalError → dynamic
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
finalinherited
statusCode int?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited