TokenStorage class abstract
Abstract interface for persisting auth tokens.
The core package defines this contract — concrete implementations live
in the http/dio packages (e.g., SecureTokenStorage using
flutter_secure_storage).
Consumers can also provide custom implementations (Hive, SharedPreferences, in-memory for tests, etc.).
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearTokens(
) → Future< void> -
getAccessToken(
) → Future< String?> -
getRefreshToken(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveAccessToken(
String token) → Future< void> -
saveRefreshToken(
String token) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited